package com.zerog.ia.customcode.action;

import java.io.*;
import java.util.*;

import com.zerog.ia.api.pub.*;

public class PropertiesFileReader extends CustomCodeAction
{
	public String getInstallStatusMessage()
	{
		return "Reading Properties File";
	}

	public String getUninstallStatusMessage()
	{
		return "";
	}

	public void install(InstallerProxy ip) throws InstallException
	{
		String propertiesFile = ip.substitute("$PROPERTIES_FILE_LOCATION$");
		String substituteVariables = ip.substitute("$SUBSTITUTE_VARIABLES$");
		String ignoreProperties = ip.substitute("$PROPERTIES_TO_IGNORE$");
		String overrideVariables = ip.substitute("$OVERRIDE_EXISTING_VARIABLES$");


		//System.err.println("propertiesFile: "+propertiesFile);
		//System.err.println("substituteVariables: "+substituteVariables);
		//System.err.println("ignoreProperties: "+ignoreProperties);
		//System.err.println("overrideVariables: "+overrideVariables);


		if(overrideVariables.equals(""))
		{
			overrideVariables = "true";
		}
		if(substituteVariables.equals(""))
		{
			substituteVariables = "true";
		}
		if(propertiesFile.equals(""))
		{
			throw new NonfatalInstallException ("PropertiesFile not specified");
		}


		Properties props = new Properties();

		try
		{
			FileInputStream fis = new FileInputStream(propertiesFile);
			props.load(fis);
			fis.close();
		}
		catch (FileNotFoundException e)
		{
			e.printStackTrace();
			throw new NonfatalInstallException ("PropertiesFile not found");
		}
		catch (IOException e)
		{
			e.printStackTrace();
			throw new NonfatalInstallException ("IOException");
		}

		Enumeration keys = props.keys();

		while(keys.hasMoreElements())
		{
			String key = (String)keys.nextElement();
			String value = props.getProperty(key);

			//System.err.println(key+": "+value);

			//Proceed only if the key is not on the ignore list
			if(ignoreProperties.indexOf(key) == -1)
			{
				//Do this if the user wants to substitute IA variables
				if(substituteVariables.equalsIgnoreCase("true"))
				{
					//  If the user wants to override variables, just set the value
					if(overrideVariables.equalsIgnoreCase("true"))
					{
						ip.setVariable(key,ip.substitute(value));
					}
					//  If the user does not want to override values, but the variable does not exist, set it
					else if(overrideVariables.equalsIgnoreCase("false") && ip.substitute("$"+key+"$").equals(""))
					{
						ip.setVariable(key,ip.substitute(value));
					}
					//else
					//{
					//	System.err.println("I did nothing");
					//}
				}
				//Do this if the user does not want to substitute IA variables
				else
				{
					// If the user wants to override variables, just set the value
					if(overrideVariables.equalsIgnoreCase("true"))
					{
						ip.setVariable(key,value);
					}
					// If the user wants to override variables, just set the value
					else if(overrideVariables.equalsIgnoreCase("false") && ip.substitute("$"+key+"$").equals(""))
					{
						ip.setVariable(key,value);
					}
					//else
					//{
					//	System.err.println("I did nothing");
					//}
				}
			}
			//else
			//{
			//	System.err.println("ignoreProperties.indexOf(key):  "+ignoreProperties.indexOf(key));
			//}

			System.err.println("Setting $"+key+"$ to "+value);
			System.err.println("Verifying...");
			System.err.println("ip.getVariable($"+key+"$): "+ ip.getVariable("$"+key+"$"));
		}
	}

	public void uninstall(UninstallerProxy up) throws InstallException
	{

	}

}